import logging
from contextlib import asynccontextmanager
from typing import AsyncGenerator

from fastapi import FastAPI

from fastfood_two.common.logger import logger_configure

logger = logging.getLogger(__name__)


@asynccontextmanager
async def app_lifespan(app: FastAPI) -> AsyncGenerator:
    """Application lifespan."""
    logger_configure(level=logging.INFO)
    logger.info("Application started")
    yield
    logger.info("Application stopped")


def app_factory() -> FastAPI:
    """Create a FastAPI application."""

    app = FastAPI(
        lifespan=app_lifespan,
    )
    return app
